@@ -5,10 +5,10 @@
 # Python library for the Google Reader API
 
 __author__  = "Matt Behrens <askedrelic@gmail.com>"
-__version__ = "0.6.3"
+__version__ = "0.7.0"
 __copyright__ = "Copyright (C) 2012  Matt Behrens"
 
-from googlereader import GoogleReader
-from auth import AuthenticationMethod, ClientAuthMethod, OAuthMethod, OAuth2Method
-from items import *
-from url import ReaderUrl
+from .googlereader import GoogleReader
+from .auth import AuthenticationMethod, ClientAuthMethod, OAuthMethod, OAuth2Method
+from .items import *
+from .url import ReaderUrl
